ClientEvent

Enum ClientEvent 

#[non_exhaustive]
pub enum ClientEvent { Throttle1Set { value: i32, }, Throttle2Set { value: i32, }, Throttle3Set { value: i32, }, Throttle4Set { value: i32, }, AxisElevatorSet { value: i32, }, Brakes, BrakesLeft, BrakesRight, AxisLeftBrakeSet { value: i32, }, AxisRightBrakeSet { value: i32, }, ParkingBrakes, }
Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Throttle1Set

Set throttle 1 exactly (0 to 16383).

Fields

value: i32

-16383 (0 throttle) to +16383 (max throttle).



Throttle2Set

Set throttle 2 exactly (0 to 16383).

Fields

value: i32

-16383 (0 throttle) to +16383 (max throttle).



Throttle3Set

Set throttle 3 exactly (0 to 16383).

Fields

value: i32

-16383 (0 throttle) to +16383 (max throttle).



Throttle4Set

Set throttle 4 exactly (0 to 16383).

Fields

value: i32

-16383 (0 throttle) to +16383 (max throttle).



AxisElevatorSet

Sets elevator position (-16383 - +16383).

Fields

value: i32

-16383 (full down) to +16383 (full up).



Brakes

Increment brake pressure. Note: These are simulated spring-loaded toe brakes, which will bleed back to zero over time.



BrakesLeft

Increments left brake pressure. Note: This is a simulated spring-loaded toe brake, which will bleed back to zero over time.



BrakesRight

Increments right brake pressure. Note: This is a simulated spring-loaded toe brake, which will bleed back to zero over time.



AxisLeftBrakeSet

Sets left brake position from axis controller (e.g. joystick). -16383 (0 brakes) to +16383 (max brakes).

Fields

value: i32

-16383 (0 brakes) to +16383 (max brakes).



AxisRightBrakeSet

Sets right brake position from axis controller (e.g. joystick). -16383 (0 brakes) to +16383 (max brakes).

Fields

value: i32

-16383 (0 brakes) to +16383 (max brakes).



ParkingBrakes

Toggles parking brake on/off.