ClientEventRequest

Enum ClientEventRequest 

#[non_exhaustive]
#[repr(u32)]
pub enum ClientEventRequest { Throttle1Set = 1_024, Throttle2Set = 1025, Throttle3Set = 1026, Throttle4Set = 1027, AxisElevatorSet = 1028, Brakes = 1029, BrakesLeft = 1030, BrakesRight = 1031, AxisLeftBrakeSet = 1032, AxisRightBrakeSet = 1033, ParkingBrakes = 1034, }
Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Throttle1Set = 1_024

Set throttle 1 exactly (0 to 16383).



Throttle2Set = 1025

Set throttle 2 exactly (0 to 16383).



Throttle3Set = 1026

Set throttle 3 exactly (0 to 16383).



Throttle4Set = 1027

Set throttle 4 exactly (0 to 16383).



AxisElevatorSet = 1028

Sets elevator position (-16383 - +16383).



Brakes = 1029

Increment brake pressure. Note: These are simulated spring-loaded toe brakes, which will bleed back to zero over time.



BrakesLeft = 1030

Increments left brake pressure. Note: This is a simulated spring-loaded toe brake, which will bleed back to zero over time.



BrakesRight = 1031

Increments right brake pressure. Note: This is a simulated spring-loaded toe brake, which will bleed back to zero over time.



AxisLeftBrakeSet = 1032

Sets left brake position from axis controller (e.g. joystick). -16383 (0 brakes) to +16383 (max brakes).



AxisRightBrakeSet = 1033

Sets right brake position from axis controller (e.g. joystick). -16383 (0 brakes) to +16383 (max brakes).



ParkingBrakes = 1034

Toggles parking brake on/off.